package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````1!@``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'"(B```B(@``(B(```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````"4B```E(@```4```````$`
M`0```)R-``"<C0$`G(T!`*0"``"\$@``!@```````0`"````I(T``*2-`0"D
MC0$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DG(T`
M`)R-`0"<C0$`9`(``&0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`!B]K\HENC6>AO:7]94MW8JVP\?(!````!`````!
M````1TY5```````#`````@`````````1````4`````@````(`````9`0!"5`
M!(`H@``!H(90@(`!```+*`2,.*`218H```A0````40```%0```!8````60``
M`&````!A````8@```&0```!E`````````&<```!H````:0```&L`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@&L
M2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%U>R)!W#3#13BGMK-
MXYXS8MOM#3J7"W^IG)N^VE<;X:<""J/@^TD`````````````````````````
M`%P2`````````P`+````````D`$```````,`%@"0`@`````````````2````
M/@,`````````````$@```!(#`````````````"(```!7`P`````````````1
M````U`,`````````````$@```!$``````````````"````#O`0``````````
M```2````Y`(`````````````$@```"\#`````````````!(````1`0``````
M```````2````@0,`````````````$0```+0``````````````!(```"K`@``
M```````````2````@P$`````````````$@```)<"`````````````!(```"$
M```````````````2````#`$`````````````$@```+("`````````````!(`
M``!T`@`````````````2````.@(`````````````$@```&$#````````````
M`!(```!+`@`````````````2````6`(`````````````$@````$!````````
M`````!$```!G`0`````````````2````XP``````````````$0```#4!````
M`````````!(```#K`@`````````````2````W0(`````````````$0```/0"
M`````````````!(```#"```````````````2````L0$`````````````$@``
M``L"`````````````!(```">`0`````````````2````RP(`````````````
M$@```!,"`````````````!(```"J`0`````````````2````10,`````````
M````$@```$,!`````````````!(````M```````````````@````;0(`````
M````````$@```"0"`````````````!(```""`@`````````````2````O`$`
M````````````$0```&0``````````````!(````!`P`````````````2````
MDP``````````````$@```/0!`````````````!(````A`P`````````````2
M````GP``````````````$@```%P!`````````````!(```!2`@``````````
M```2````B0(`````````````$@```"(!`````````````!(```!6````````
M```````2````%@$`````````````$@```),!`````````````!(```"=`@``
M```````````2````\```````````````$@```&8"`````````````!(````W
M`P`````````````2````>P(`````````````$@```'4!`````````````!(`
M``!S```````````````2````6`,`````````````(0````@#````````````
M`!(```#4```````````````2````4P$`````````````$@```#P`````````
M`````"````!9`P`````````````1````TP(`````````````$@```"D"````
M`````````!(```!@`@`````````````2````!0(`````````````$@```,`"
M`````````````!(````Q`@`````````````2````VP$`````````````$@``
M`/$#``!8H`$``````!``%P#=`P``Y$<``'P````2``T`%00``/@X``"8"@``
M$@`-`%(#``"`%0``Q`(``!(`#0"C`P``V#````0````2``T`M`,``$"0`0``
M````$``7`)P$``#<,```L`(``!(`#0#)!```D$,``%0$```2``T`B`0``$"0
M`0``````$``7`/P#``",,P``*````!(`#0`O!```X$@```0````1``\`;@0`
M`%B@`0``````$``7`',$``!8H`$``````!``%P"4!```'"\``%`````2``T`
MJ00``.@W```0`0``$@`-`+L$```8-P``N````!(`#0`B!````)`!```````0
M`!8`"00``+0S```D`0``$@`-`.D#``!`D`$``````!``%@!D!```/)`!``0`
M```1`!8`DP,``,!(```$````$@`-`%0$``!@2```8````!(`#0`H!```1!@`
M```````2``T`)`0```"0`0``````(``6`,(#``#0-P``&````!(`#0#P`P``
M6*`!```````0`!<`/@0``-PO``#\````$@`-`'L$``#8-```0`(``!(`#0``
M;&EB<&5R;"YS;RXU+C,P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!R
M96%D`%]?97)R;F]?;&]C871I;VX`8VQO<V4`;'-E96LV-`!O<&5N-C0`;&EB
M8RYS;RXV`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL
M`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN
M=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I
M<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C
M:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?
M8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&0M;&EN=7@N<V\N,P!?7W-T
M86-K7V-H:U]G=6%R9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R
M7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?
M=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY
M7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`%]?8G-S7W-T87)T
M`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E
M;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-```````
M`````@`"``(``@`"`````P`"``(``@`$`````@````(```````(``@`"``(`
M`@`"`````````````@`"``(```````,````"``,``@`"```````"``(``@``
M`````@````,``@```````@`"`````````````@````(``@`"```````"``(`
M`````````@`"``(``@`#``(``@`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`<P,``!``
M```@````%&EI#0``!`#?!`````````$``0#+`0``$````"`````4:6D-```#
M`-\$`````````0`!`!H"```0`````````!1I:0T```(`WP0```````"<C0$`
M%P```*"-`0`7````P(\!`!<```#HCP$`%P```/"/`0`7````!)`!`!<````,
MD`$`%P```!"0`0`7````&)`!`!<````<D`$`%P```""0`0`7````))`!`!<`
M```HD`$`%P```#"0`0`7````-)`!`!<````\D`$`%P```,2/`0`5!0``R(\!
M`!4(``#,CP$`%0T``-"/`0`5$```U(\!`!4:``#8CP$`%1P``-R/`0`5'P``
MX(\!`!4J``#DCP$`%2X``.R/`0`5.```](\!`!5"``#XCP$`%4<``/R/`0`5
M2```P(X!`!8#``#$C@$`%@0``,B.`0`6!0``S(X!`!8'``#0C@$`%@D``-2.
M`0`6"@``V(X!`!8+``#<C@$`%@P``.".`0`6#@``Y(X!`!8/``#HC@$`%A$`
M`.R.`0`6$@``\(X!`!83``#TC@$`%A0``/B.`0`6%0``_(X!`!86````CP$`
M%A<```2/`0`6&```"(\!`!89```,CP$`%AL``!"/`0`6'0``%(\!`!8>```8
MCP$`%B```!R/`0`6(0``((\!`!8B```DCP$`%B,``"B/`0`6)```+(\!`!8E
M```PCP$`%B8``#2/`0`6)P``.(\!`!8H```\CP$`%BD``$"/`0`6*@``1(\!
M`!8K``!(CP$`%BP``$R/`0`6+0``4(\!`!8O``!4CP$`%C```%B/`0`6,0``
M7(\!`!8R``!@CP$`%C,``&2/`0`6-```:(\!`!8U``!LCP$`%C8``'"/`0`6
M-P``=(\!`!8Y``!XCP$`%CH``'R/`0`6.P``@(\!`!8\``"$CP$`%CT``(B/
M`0`6/@``C(\!`!8_``"0CP$`%D```)2/`0`600``F(\!`!9$``"<CP$`%D4`
M`*"/`0`61@``I(\!`!9)``"HCP$`%DH``*R/`0`62P``L(\!`!9,``"TCP$`
M%DT``+B/`0`63@``O(\!`!9/```(0"WIC0$`ZPB`O>@$X"WE!."?Y0[@C^`(
M\+[E/'P!``#&C^(7RHSB//R\Y0#&C^(7RHSB-/R\Y0#&C^(7RHSB+/R\Y0#&
MC^(7RHSB)/R\Y0#&C^(7RHSB'/R\Y0#&C^(7RHSB%/R\Y0#&C^(7RHSB#/R\
MY0#&C^(7RHSB!/R\Y0#&C^(7RHSB_/N\Y0#&C^(7RHSB]/N\Y0#&C^(7RHSB
M[/N\Y0#&C^(7RHSBY/N\Y0#&C^(7RHSBW/N\Y0#&C^(7RHSBU/N\Y0#&C^(7
MRHSBS/N\Y0#&C^(7RHSBQ/N\Y0#&C^(7RHSBO/N\Y0#&C^(7RHSBM/N\Y0#&
MC^(7RHSBK/N\Y0#&C^(7RHSBI/N\Y0#&C^(7RHSBG/N\Y0#&C^(7RHSBE/N\
MY0#&C^(7RHSBC/N\Y0#&C^(7RHSBA/N\Y0#&C^(7RHSB?/N\Y0#&C^(7RHSB
M=/N\Y0#&C^(7RHSB;/N\Y0#&C^(7RHSB9/N\Y0#&C^(7RHSB7/N\Y0#&C^(7
MRHSB5/N\Y0#&C^(7RHSB3/N\Y0#&C^(7RHSB1/N\Y0#&C^(7RHSB//N\Y0#&
MC^(7RHSB-/N\Y0#&C^(7RHSB+/N\Y0#&C^(7RHSB)/N\Y0#&C^(7RHSB'/N\
MY0#&C^(7RHSB%/N\Y0#&C^(7RHSB#/N\Y0#&C^(7RHSB!/N\Y0#&C^(7RHSB
M_/J\Y0#&C^(7RHSB]/J\Y0#&C^(7RHSB[/J\Y0#&C^(7RHSBY/J\Y0#&C^(7
MRHSBW/J\Y0#&C^(7RHSBU/J\Y0#&C^(7RHSBS/J\Y0#&C^(7RHSBQ/J\Y0#&
MC^(7RHSBO/J\Y0#&C^(7RHSBM/J\Y0#&C^(7RHSBK/J\Y0#&C^(7RHSBI/J\
MY0#&C^(7RHSBG/J\Y0#&C^(7RHSBE/J\Y0#&C^(7RHSBC/J\Y0#&C^(7RHSB
MA/J\Y0#&C^(7RHSB?/J\Y0#&C^(7RHSB=/J\Y0#&C^(7RHSB;/J\Y0#&C^(7
MRHSB9/J\Y0#&C^(7RHSB7/J\Y0#&C^(7RHSB5/J\Y0#&C^(7RHSB3/J\Y0#&
MC^(7RHSB1/J\Y0````!HPI_E:#*?Y7!`+>D,P(_@(-!-XA0`C>40$(WE#""-
MY0,PG.<0$(WB#""-XA0`C>)`0I_E`#"3Y1PPC>4`,*#CF?__ZS`BG^4$0(_@
M+#*?Y0(@E.<#`)3G`A"@X;@,`.L<,I_E`S"4YP!@T^4``%;C6```"@PRG^4#
M4)3G``"5Y=K__^O&(]#E`#"@X0(@@N/&(\/E``"5Y=3__^L4,)WE!3"#X@<!
M<^/&(]#E`2""X\8CP.5E``"*`P&@X5S__^L0$)WEP.&?Y10@G>6\P9_E#N"/
MX`S`C^`!`%+C`.">Y0`PH.$``)'E``"#Y:`!G^4(X(/E``"/X`0`@^64`9_E
M!."@XP``C^`,`(/E#`"@X00`0<((,(SE!.",Y0(!@,`,P(/"`P``V@3@L>4$
MX*SE`0!0X?O__QI<49_E`!"@XPW!@N(%4(_@$`"5Y0`0C>4,$8/G1!&?Y0,@
M@N(!$(_@<O__ZP!`4.(G```*,%&?Y1A@C>(%4(_@$`"5Y1?__^L@`9_E!A"@
MX0``C^`N!`#K``!0XR````H,,9_E`S"/X!``D^7X_O_K6O__Z_P@G^6\,)_E
M`B"/X`,PDN<`()/E'#"=Y0(@,^`G```:!`"@X2#0C>)P@+WH#___Z]`@G^4"
M((_@``!0XQ``@N4<```*XO[_ZXPPG^4#4)3G``"5Y7K__^MQ9\#EF___ZA``
ME>5A___K`$"@X=/__^H,`)7E``!0XP$```H-#`#KV?__ZH``G^4&$*#A``"/
MX`($`.L``%#C#`"%Y=+__PKU___J9#"?Y60`G^4#$)3G``"/X"#__^L!`*#C
M"?__Z\_^_^L@>0$`&`$``.1X`0`X`0``0`$``"0!```@`0``Y'D!`.AY`0"@
M-0``E#4``'AY`0"(&```2'D!`-`R```@>0$`>'<!`-QX`0"\,0``,`$``'`S
M````L*#C`."@XP00G>0-(*#A!"`MY00`+>4HH)_E)#"/X@.@BN`@P)_E#,":
MYP3`+>48,)_E`S":YQ0`G^4``)KGUO[_ZRS__^LH=@$`#`$``#0!```\`0``
M%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!T/[_Z@AV`0`L`0``+`"?Y2PPG^4`
M`(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX7!W
M`0!L=P$`U'4!`!0!```X`)_E.!"?Y0``C^`!$(_@`!!!X*$_H.%!$8/@)#"?
MY<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A+'<!`"AW`0"$=0$`
M1`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E$$`MZ0,PDN<`
M`%/C`@``"B@PG^4#`)_G0/[_Z\K__^L<,)_E`2"@XP,PC^``(,/E$("]Z-QV
M`0!(=0$`$`$``'1V`0"<=@$`T/__ZN@MG^7H/9_E`B"/X/!/+>FCWTWB`S"2
MYPW@H.%`P(#B@&"`X@X0H.$`4*#C`#"3Y80RC>4`,*#C!$`<Y0AP'.4D-*#A
M_SP#XF<H)^`D/(/A!(2@X2(DH.$$/(/A",",XO](".+_+,+C!#"#X6<D(N`&
M`%SA!%"!Y0Q0@>4(,('E`""!Y1`0@>+J__\:?N^.X@@03>(`0*#C`<"@X4A0
MD>5P,)'E=""<Y4QPG.48@)'E"&"QY04P(^`<4)SE"#`CX`3`D>4'("+@!C`C
MX`4@(N`,("+@H\^@X8+`C.&#,(SA#@!1X81`@>6`,('EZ?__&@APD.4,X)#E
M)Q&@X0X?@>$`8)#E$%"0Y0=/@>$8$)#EX#R?Y03`D.4`D)WE`8`EX*;MH.$@
M$)#E`Y"9X(SBCN$!D)G@AN*.X0G@GN`8D)#E!!`EX`>`".`)@"C@"*"=Y080
M`>`FD:#A#)^)X07`(>`8$)#E".">X`.@FN`&GXGA`1":X!"@G>4)@"3@#!"1
MX.[-H.$,$)'@#H`(X`/`FN!NX:#A&+"=Y02`*.`%P)S@X:V@X0C`G.`.@"G@
M"L"<X`&`".`#H)O@81&@X2"PG>4$0)K@"8`HX.RMH.$(@)3@`4`NX`J`F.`,
M0`3@`Z";X&S!H.$HL)WE#D`DX`F0FN`$D)G@Z*V@X0Q`(>`*D)G@"$`$X`.@
MF^!H@:#A,+"=Y0[@FN`!0"3@Z:V@X01`GN`(X"S@"D"4X`G@#N`#H)O@:9&@
MX3BPG>4!$)K@#.`NX.2MH.$.X)'@"1`HX`K@GN`$$`'@`Z";X&1!H.%`L)WE
M"!`AX`S`FN`!P)S@[JV@X000*>`*P)S@#A`!X`.@F^!NX:#A2+"=Y0D0(>`(
M@)K@`8"8X.RMH.$.$"3@"H"8X`P0`>`#H)O@;,&@X5"PG>4$$"'@"9":X`&0
MF>#HK:#A#!`NX`J0F>`($`'@`Z";X&B!H.%8L)WE#A`AX`1`FN`!0)3@Z:V@
MX0@0+.`*0)3@"1`!X`.@F^!ID:#A8+"=Y0P0(>`.X)K@`>">X.2MH.$)$"C@
M"N">X`00`>`#H)O@9$&@X6BPG>4($"'@#,":X`'`G.#NK:#A!!`IX`K`G.`.
M$`'@`Z";X&[AH.%PL)WE"1`AX`B`FN`!@)C@[*V@X0X0).`*@)C@#!`!X`.@
MF^!LP:#A>+"=Y000(>`)D)K@`9"9X.BMH.$,$"[@"I"9X`@0`>`#H)O@:(&@
MX8"PG>4$0)K@#A`AX.FMH.$!$)3@"$`LX`H0D>`)0`3@`Z";X&F1H.&(L)WE
M#N":X`Q`).#AK:#A!$">X`G@*.`*0)3@`>`.X`.@F^!A$:#AD+"=Y0S`FN`(
MX"[@`:`IX`[@G.#DS:#A#.">X`2@"N`#P)O@":`JX)BPG>4(@)S@"H"8X&3!
M(>#NK:#A"H"8X`[`#.`#,)O@"9"3X`&@+.`*H)G@Z,V@X;`YG^4,H)K@H,"=
MY6Z1H.%DL2G@`\"<X`$0G.`(P"O@#,"1X*@0G>7J[:#A#N"<X&BQ*>`#$)'@
M9$&@X03`D>`*L"O@[DV@X0O`G.`$P)S@L$"=Y6H1H.%HH2'@`T"4X+BPG>4.
MH"K@"9"4X`J0F>#L3:#A!)"9X&ZA(>`#0)O@:(&@X<"PG>4,H"K@"$"4X&S!
MH.'IC:#A"D"4X`A`E.!NH2S@`X";X`F@*N#(L)WE`8"8X`J`F.#D':#A`8"8
MX&FA+.`#$)O@;N&@X02@*N`.X)'@"N">X&01H.'H3:#A!.">X-!`G>5IL2'@
M`T"4X`S`E.`(H"O@V$"=Y0J@G.#NS:#A#*":X&BQ(>`#P)3@:9&@X0E`G.`.
ML"O@;L&@X0M`E.#J[:#A#D"4X.#@G>5HD2S@`^">X.BPG>4*D"G@`>">X`G@
MGN#D':#A`>">X&J1+.`#$)O@:(&@X?"PG>4$D"G@"("1X`F`F.!D$:#A[DV@
MX01`F.!JD2'@`X";X`Z0*>`,@)C@"8"8X.3-H.$,@)C@^,"=Y6ZQ(>!JH:#A
M`\"<X`@@C>+XD)+E"L"<X`0@*^`"()S@9,&@X>A-H.$$()+@;J$LX`-`F>`(
MH"K@`4"4X`@1G>7BG:#A"D"4X`E`E.!HH2S@;N&@X0,0D>`0L9WE`J`JX`X0
MD>!B(:#AY.V@X0H0D>`.$)'@:*$BX`/@F^`$H"K@#.">X!C!G>7AG:#A"N">
MX`G@GN!DH2+@:(&@X0/`G.`@L9WE`:`JX`C`G.`*P)S@81&@X>ZMH.$"@*#A
M"B"<X`/`F^!DH2'@#J`JX`B`G.`HP9WEXIV@X0J`F.`)@)C@;J$AX&1!H.$#
MP)S@,+&=Y0*@*N`$P)S@8B&@X>A-H.$*P)S@!,"<X&ZA(N`#0)O@"*`JX`$0
ME.`X09WE:(&@X>R=H.$*$)'@"1"1X`B@(N`#,)3@;N&@X4"QG>4,H"K@#N"3
MX&S!H.'4-I_EX4V@X0K@GN`,H(CA!.">X`&@"N`#0)O@#+`(X&$1H.%(D9WE
M"["*X0)`E.`!H(SA[BV@X0M`E.`"0)3@`;`,X`Z@"N`#()G@"""2X`N`BN%N
MX:#A`H"8X.2]H.$.(*#A#J"!X0O@F.!0@9WE`K`!X`.`F.`$H`K@"Z"*X61!
MH.%8D9WE#,"8X`S`FN`$@(+A[JV@X0K`G.`$L`+@#H`(X`.0F>`!D)G@"Q"(
MX0D0D>#LC:#A;N&@X0@0D>!@@9WE#K"$X0RP"^`.D`3@`X"8X&S!H.$)D(OA
M`B"8X&BQG>4,H([A`B"9X.&-H.$(@)+@`:`*X`P@#N`#L)O@`J"*X01`F^#H
M+:#A!$":X&$1H.$"0)3@<"&=Y0&PC.$(L`O@`:`,X`,@DN!H@:#A"J"+X7B1
MG>4.()+@`B":X`C@@>'DK:#A"J"2X`3@#N`((`'@`Y"9X`+@CN$,P)G@ZBV@
MX0S`GN!D0:#A`L"<X(`AG>4$D(CA"I`)X`3@".`#()+@:J&@X0[@B>$!()+@
MB)&=Y0H0A.$"()[@[.V@X0X@DN`,$`'@"N`$X`.0F>!LP:#A")"9X)"QG>4.
M$('A#("*X>+MH.$)$)'@#A"1X`*`".`,X`K@`[";X&*1H.$$0)O@#B"(X9BQ
MG>4)X(SA!""2X.%-H.$$()+@`>`.X`F`#.`#0)O@81&@X:"QG>4(@([A"D"4
MX`'@B>$$0)C@XHV@X0A`E.`!H`G@`X";X`+@#N`,@)C@8B&@X0K@CN&HH9WE
M`L"!X0C@GN#DC:#A".">X`*P`>`#H)K@!,`,X&2!H.$)D)K@"\",X;"QG>4(
M0(+A"<"<X.Z=H.$)P)S@"*`"X`.0F^`.0`3@"D"$X6[AH.&XH9WE`1"9X`$0
ME.`.D(CA[$V@X000D>`,D`G@#K`(X`.@FN!L0:#A"[")X0(@FN#`H9WE!)".
MX>'-H.$"()O@#""2X`2P#N`#H)K@`9`)X&'!H.$+D(GA"(":X,BQG>4,$(3A
M"("9X.*=H.$)@)C@#*`$X`.0F^`"$`'@T+&=Y6(AH.$.X)G@"A"!X0X0D>`"
MH(SAZ.V@X0X0D>`(H`K@`I`,X`/@F^!H@:#A"9"*X03@GN#8H9WE"$""X0[@
MF>#AG:#A">">X`%`!.`(D`+@`S":X`E`A.'@L9WE#,"3X&0SG^7NG:#A#,"4
MX`G`G.!A02C@`[";X`*PF^`.0"3@Z"&=Y6[AH.'LG:#A!$";X`E`E.!AD2[@
M`R"2X`R0*>`(()+@\(&=Y0D@DN#DG:#A":"2X&$1H.%L(2[@`X"8X`$0F.`$
M@"+@^"&=Y61!H.$($)'@ZHV@X0@0D>!L@23@`R"2X`J`*.`.()+@`.*=Y0@@
MDN#AC:#A"+"2X&S!H.%J(23@`^">X`S`GN`!X"+@""*=Y6$1H.$.P)S@Z^V@
MX0[@G.!J@2'@`\"2X`N`*.`$P)S@$$*=Y0C`G.#NC:#A","<X&HAH.%K@2'@
M`T"4X`Z`*.`"0)3@&"*=Y6[AH.'LG:#A"$"4X`E`E.!K@2[@`R"2X`R`*.`!
M()+@(!*=Y0@@DN#DG:#A":"2X&N!H.%L(2[@`Q"1X`@0D>`$@"+@*"*=Y61!
MH.$($)'@ZHV@X0@0D>!L@23@`R"2X`J`*.`.()+@,.*=Y0@@DN#AG:#A";"2
MX&S!H.%J(23@`^">X`S`GN`!X"+@."*=Y6$1H.$.P)S@Z^V@X0[`G.!JX2'@
M`R"2X`1`DN`+("[@0.*=Y0(@E.#L3:#A!$"2X&J1H.%K(2'@`^">X`F0GN`,
MX"+@2"*=Y6S!H.$.D)G@Y.V@X0[@F>!K@2S@`R"2X`$0DN`$("C@4(*=Y>ZM
MH.$"$)'@"A"1X&21+.!K(:#A`X"8X`Z0*>`"@)C@6"*=Y>&MH.$)@)C@;I&@
MX0J`F.!DX2G@`R"2X`'@+N`,()+@8,*=Y0X@DN#H[:#A#B"2X&1!H.%AX2G@
M`\"<X`C@+N`$0)S@:,*=Y6B!H.'BK:#A#D"4X`I`E.`)X*#A8:$HX`.0G.`"
MH"K@<,*=Y0Z0F>`*D)G@8N&@X>0MH.$"D)G@81&@X0,@G.`.H"C@`2"2X`2@
M*N!X$IWE"B"2X.G-H.$,P)+@9$&@X0,PD>`$("[@!C"3X`D@(N`(,)/@`C"3
MX.PMH.$",)/@&""0Y6F1H.$'P)S@!9"9X`)`E.`@()#E`#"`Y0+@GN!D()_E
M3#"?Y0`0H.,"((_@","`Y1"0@.480(#E(."`Y000@.4,$(#E%!"`Y1P0@.4D
M$(#E`S"2YP`@D^6$,IWE`B`SX`$``!JCWXWB\(^]Z-_Z_^OD=`$`&`$``)EY
M@EJAZ]ENW+P;C];!8LI$9P$`T#"?Y?!'+>D`D%#B`S"/X"P```K`()_E`C"3
MYP"`D^4``%CC*0``"@`@V>4!<*#A/5!2X@%0H!,``%+C`%"@`P``5>,1```:
M`$"8Y0``5.,,```*"&"@X04@H.$)$*#A!`"@X3_[_^L``%#C`@``&@4PU.<]
M`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O_
M_QH)4$7@YO__Z@A@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__
MZ@A`H.'K___JU&8!`$@!``"H()_EJ#"?Y0(@C^!P0"WI`S"2YYQ0G^4(T$WB
M`$"@X0`PD^4$,(WE`#"@XP50C^`-8*#A!A"@X00`H.&W___K``!0XPX```IL
M,)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^HT()_E)#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`0``
M&@C0C>)P@+WH=/K_Z_AE`0`8`0``U&4!`$@!``!T90$`\$\MZ0`PT>4<(I_E
M/0!3XQ@RG^4"((_@`4"@X0,PDN<!0($"#-!-X@!0H.$$`*#A`#"3Y00PC>4`
M,*#CF_K_ZPT0H.'H@9_E"("/X`!@H.$%`*#A@/__ZP"04.)"```*DOK_ZP8`
M4.$Y```JQ#&?Y0!PG>4#@)CG!W&@X0``U>4](%#B`2"@$P``4.,`(*`#``!2
MXP4```H%(*#A`3#RY0``4^,]`%,3^___&@4@0N`"`(;B`@"`X`!@F.5I^O_K
M``!0XP<`AN=1```*`""8Y0`0G>4%`*#A`3#0Y`$1DN<]`%/C``!3$P`PP>4&
M```*`2"!X@$PT.0"$*#A``!3XST`4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$P
MU.0!,.+E``!3X_O__QH``*#C""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`S
MX#8``!H,T(WB\(^]Z`&02>(!,-3D`3#IY0``4^/[__\:[O__ZL0PG^4#@)CG
M`*"8Y0`PFN4``%/C)0``"@HPH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!
M$:#AE#"?Y0,PC^``()/E``!2XP\``!H!(*#C`0"@X0`@@^4G^O_K`+!0XA``
M``H)<:#A"A"@X0<@H.'<^?_K`+"(Y0$PB>(`(*#C`R&+YP"0C>6@___J"@"@
MX?CY_^L``%#C`+"@X0EQH!$``(CE\___&@``X./#___J`Y"@X0@0H./>___J
MY/G_ZRAE`0`8`0``]&0!`$@!```(9`$`)&4!`&PAG^5L,9_E`B"/X/!!+>D#
M,)+G>-!-X@!`4.(`,)/E=#"-Y0`PH.,"```*`##4Y0``4^,)```:/"&?Y30Q
MG^4"((_@`S"2YP`@D^5T,)WE`B`SX$4``!IXT(WB\(&]Z.GY_^L`4%#B\O__
M"@QQG^4'<(_@!0"@X33Z_^L``%#C)@``"A,PT.43@(#B+@!3XR<```H3,-#E
M+@!3XRH```H$`*#A\/G_ZP!@H.$(`*#A[?G_ZP``AN`"`(#BV/G_ZP<PH.$`
M(.#C`1"@XQ`!C>@`8*#A\_G_ZP80H.$(((WB`P"@XR+Z_^L!`'#C!@"@X0,`
M``H8,)WE#SH#X@$)4^,8```*HOG_ZP8`H.&"^?_K!0"@X0WZ_^L``%#CV/__
M&@4`H.$A^O_K!`"@X8/Y_^O`___J`3#8Y0``4^/,__\*$S#0Y2X`4^/4__\:
M`3#8Y2X`4^/1__\:`C#8Y0``4^/#__\*S?__ZJ3__^OE___J@?G_Z_!B`0`8
M`0``N&(!`/0<``"4P)_EE#"?Y0S`C^`00"WI<-!-X@,PG.<`$*#A`$"@X0T@
MH.$#`*#C`#"3Y6PPC>4`,*#C^?G_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3
MXP$)4Q,)```*1""?Y3PPG^4"((_@`S"2YP`@D^5L,)WE`B`SX`<``!IPT(WB
M$("]Z`0`H.$"$*#CQOG_ZQ`/;^&@`J#A[___ZE;Y_^ML80$`&`$``!1A`0#P
M02WI%.&?Y0':3>(0P9_E"-!-X@[@C^``0*#A!`&?Y0S`GN<!.HWB!'"-XO@@
MG^4!8*#A``"/X`<0H.$$,(/B`,"<Y0#`@^4`P*#C4?G_Z]@PG^4#,(_@`,!0
MXB4``-H(4(WB`8!,X@A0A>#`()_E!!!5Y0(PD^<``%'C`%"3Y1H``!H``%CC
M'0``"@@@H.$O$*#C!P"@X97Y_^L``%#C%P``"@4`H.&X^?_K"#"@X0<@H.$$
M$*#AG/G_ZW00G^5<()_E`1"/X`$ZC>("()'G!#"#X@`0DN4`()/E`1`RX`T`
M`!H!VHWB"-"-XO"!O>@,@*#AY/__ZC0@G^4",)/G`%"3Y04`H.&@^?_K!B"@
MX000H.$<^?_KY___Z@OY_^NX8`$`&`$```P;``#_#P``>&`!`"`!```(8`$`
M$$`MZ3!`G^4P,)_E!$"/X`,PE.<``)/EC?G_ZR`@G^4@,)_E(!"?Y0(@E.<#
M,(_@$$"]Z`$0C^!&^?_JA%\!`"`!```<`0``"%D``.`9``!4,)_E5""?Y0,P
MC^`00"WI`D"3YPC03>(``)3E>/G_Z^+__^L``)3E=?G_ZP`@H.,L,)_E!""-
MY2@0G^4H()_E`S"/X`(@C^`!$(_@`#"-Y4'Y_^L(T(WB$("]Z#A?`0`@`0``
M9!P``)@9``#8$P``W!"?Y7!`+>G8()_E`MI-XAC03>(!$(_@`B"1YP(ZC>(4
M,(/B`""2Y0`@@^4`(*#C_?C_Z[`PG^4,0(WB`S"/X`0PC>6D,)_E`6J-XJ`@
MG^4#,(_@`1"@XQ!@AN(``(WE!`"@X07Y_^L$`*#A!A"@X0$JH./(^/_K`$!0
MX@!0H+,(``"Z`0"$XMOX_^L`4%#B!```"@80H.$$(*#AFOC_ZP`PH.,$,,7G
M2!"?Y30@G^4!$(_@`CJ-X@(@D><4,(/B`!"2Y0`@D^4!$#+@`P``&@4`H.$"
MVHWB&-"-XG"`O>B;^/_KO%X!`!@!``!8&0``.!D```$0```@7@$`O___ZG3"
MG^7P3RWI<"*?Y4+=3>(,T$WB#,"/X`!0H.%@`I_E`B"<YT(]C>(88(WB`8"@
MX0``C^`&$*#A!#"#X@`@DN4`((/E`""@XZC]_^LO$*#C`$"@X04`H.&_^/_K
M``!0XQ$```H<`I_E!1"@X0``C^`'_O_K!0"@X0P2G^7\(9_E`1"/X$(]C>("
M()'G!#"#X@`0DN4`()/E`1`RX'4``!I"W8WB#-"-XO"/O>@%`*#AH_C_Z]01
MG^4!$(_@`'"@X0@`H.'1^/_K`)!0XN3__PJ\,9_E";"@X0,PC^`4,(WEL#&?
MY;"!G^4#,(_@$#"-Y0`PV^4(@(_@``!3XST```H``%3C!```"@L0H.$$`*#A
M)?C_ZP``4.-!```*"P"@X8?X_^L!P$#B#"#;YPPPB^`O`%+C`."@X0H``!H"
MD$#B"9"+X`.02>`#P$S@`R"@X0"@H.,,X(/@":##Y@$0<N4O`%'C^O__"@$P
MA^(.X(/@`0I>X[K__ZH@,9_EA*"-X@,PC^`!*J#C`1"@XP0PC>4*`*#A"#"@
MX0A0C>4`L(WE=OC_ZP8@H.$*$*#A`P"@XZ7X_^N(D(WB``!0XP,``!I@,!GE
M#SH#X@()4^,:```*S!"?Y0``H.,!$(_@B_C_ZP"PH.$``%OCG?__"@`PV^4`
M`%/CP?__&@``5.,:```*`##4Y2X`4^,"```*%+"=Y0'@H./3___J`3#4Y0``
M4^/Y__\:?!"?Y0``H.,!$(_@=OC_ZP"PH.'I___J`1"@XPH`H.%N^/_K``!0
MX]___QI4`)_E"A"@X0``C^",_?_K"@"@X??W_^N"___J$+"=Y0'@H..[___J
M]??_Z[Q=`0`8`0``:!@``#@8``!070$`_!<``#`7```@%P``Q!<``$`7``#<
M%@``B!8``$P6````,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!,-+D``!3X_K_
M_QH>_R_A$$`MZ0!`4.(N```*`##4Y0``4^,K```*$_C_ZP$P0.(#,(3@`P!4
MX0,@H#$#```Z*```Z@0`4N$",*#A)0``"@(PH.$!$%+D+P!1X_C__PH#`%3A
M'P``*@$P0^(#`%3A'@``"@`@T^4O`%+C^?__&@$P0^(#``#J`!#3Y0$P0^(O
M`%'C`@``&@,`5.$#(*#A^/__.@0@0N`",(+B`0I3XQ4``(IH`)_E!!"@X0``
MC^``0*#A`2""X@$ZH..H]__K!`"@X1"`O>A(`)_E$$"]Z```C^"E]__J`P!4
MX>/__QH`,-/E+P!3XP4```HH`)_E$$"]Z```C^"<]__J``"@XQ"`O>@4`)_E
M$$"]Z```C^"6]__J\%L!`&`4``#T%```)!0``-#!G^4P0"WI#,"/X,A1G^7(
M09_E#,",X@\`O.@%4(_@--!-X@1`E><(X(WB`$"4Y2Q`C>4`0*#C#P"NZ`\`
MO.@/`*[HF`&?Y0`PG.4``(_@L##.X=[\_^N(`9_EB%&?Y0``C^#:_/_K@`&?
MY050C^```(_@UOS_ZW0!G^4$0(WB``"/X-+\_^MH`9_E``"/X,_\_^M@`9_E
M``"/X,S\_^M8`9_E``"/X,G\_^M0`9_E``"/X,;\_^L%`*#AQ/S_ZT`!G^4`
M`(_@P?S_ZS@!G^4``(_@OOS_ZS`!G^4$$*#A``"/X(+\_^L`$%#B`0``"@4`
MH.'G_/_K%`&?Y000H.$``(_@>OS_ZP`04.("```*``&?Y0``C^#>_/_K^`"?
MY000H.$``(_@<?S_ZP`04.(1```*Y`"?Y0``C^#5_/_KW!"?Y=P`G^4!$(_@
M``"/X-#\_^O0()_E@#"?Y0(@C^`#,)+G`""3Y2PPG>4"(#/@%P``&C30C>(P
M@+WHK`"?Y000H.$``(_@6?S_ZP`04.(#```*F`"?Y0``C^"]_/_KYO__ZHP0
MG^4*(*#C`1"/X!D`C>*H]__K``!0X]___QIT`)_E(Q"-X@``C^"Q_/_KVO__
MZA_W_^MP4P``N%D!`!@!``!\%```=!0``*P4``!L%```:!0``&04``!H%```
M^!,``%P4``!@%```V!,``%`4``!$%```_!(``#04``!D$P``0!0``*03``!X
M6`$`Y!,``'03``#0$P``1!,``)@PG^68$)_EF""?Y0,PC^`$X"WE`1"/X```
MD^4"()'G#-!-X@$`<.,`()+E!""-Y0`@H.,)```*;""?Y60PG^4"((_@`S"2
MYP`@D^4$,)WE`B`SX!```!H,T(WB!/"=Y$@`G^4-$*#A``"/X!#\_^L``%#C
M!```"@``T.4P`%#C``!0$P$`H!,``*`#(#"?Y0,PC^```(/EYO__ZMWV_^O<
M6`$`@%<!`!@!``!45P$`9!(``%A8`0`00"WIM_;_Z[#V_^L``%#C``"0%1"`
MO>CL()_E\$`MZ>@PG^7H8)_E`B"/X!S03>(#,)+G!F"/X`!0H.$0$(WB!@"@
MX0`PD^44,(WE`#"@X^G[_^L%$*#A`$!0X@(```H`,-3E``!3XPP``!JD`)_E
M``"/X$G\_^N<()_EC#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@&P``&AS0C>+P
M@+WH@?;_ZP``4./R__\:!0"@X>;V_^L`<*#A!`"@X>/V_^L``(?@`@"`XL[V
M_^M,,)_E"$"-Y0,PC^`$,(WE0#"?Y0`@X.,#,(_@`1"@XP!0C>4`0*#AY/;_
MZP00H.$&`*#A)OS_Z]O__^J4]O_KM%8!`!@!``!@$@``)!(``%Q6`0#L$```
MX!```/!/+>ELR9_E;$F?Y8'<3>)HZ9_EE-!-X@S`C^`$0(_@#N"4YX$\C>(`
M@*#A!P"<Z1E.C>(`X)[EC."#Y0#@H..,,(/B$%",XO@P1.('`(/H#P"UZ.#@
M1.(/`*[H`P"5Z"C`C.(#`([H!P"<Z.PP1.('`(/H"`F?Y3!PC>('$*#A``"/
MX)+[_^OX.)_E`S"/X"`PC>4`4%#B`@``"@`PU>4``%/C'@$`&HK__^L`8%#B
M]0``"@8`H.&:]O_K@`"@X0$`@.*%]O_K`##6Y0``4^,`H*#A#0``"JRXG^4*
M4*#A"["/X`,@H.$%`*#A`""-Y0LPH.$`(.#C`1"@XYCV_^L!(/;E`E"%X@``
M4N/U__\:>`B?Y=Q01.(``(_@`@``Z@0`E>0``%#C#0``"@<0H.%G^__K`&!0
MXOC__PH`,-;E``!3X_7__PJ\_/_K``!0X_+__PH&`*#A,_;_ZP"P4.(3```:
M`)"@X_A@1.(),83@^%`3Y0``5>,,```*`;")X@NQAN``,-7E``!3XP<```H%
M`*#AJ?S_ZP&0B>(``%#C0P``&@10F^0``%7C]/__&@"PH.,+`*#A6O;_ZP!0
MH.$*`*#A5_;_ZP!0A>`!6X7B!%"%X@4`H.%`]O_KL#>?Y;`GG^4#,(_@!#"-
MY:@WG^4"((_@`S"/X`$0H.,(((WE#*"-Y0`@X.,`L(WE`&"@X5/V_^L&`*#A
M!QV@XUGV_^L!`'#C`P``&DKV_^L`$)#E$0!1XZT``!H'(*#A!A"@X0,`H..%
M]O_K`*!0XAX```I()Y_E(!"=Y0`PF.4"$)'G/">?Y0``D>4"((_@`1"@XP!@
MC>52]O_K`%"@XR07G^7X)I_E`1"/X($\C>("()'GC#"#X@`0DN4`()/E`1`R
MX/L!`!H%`*#A@=R-XI30C>+PC[WH!0"@X=OU_^L``%#CJ?__"@"PH.&Y___J
M4#$4Y0\Z`^(!"5/CW/__&DBQ%.6V]?_K``!;X=C__QI0,13E@SN@X:,[H.$'
M#5/CT___&@4`H.'U]?_K!Q"@X0!0H.&4!I_E``"/X.WZ_^L``%#CBP``"@!P
MF.6_]?_K`!"@X0<`H.$J_?_K`'!0XH0```H'`*#A]_7_ZP,`4.,`D*#A#```
MFE06G^4$`$#B``"'X`$0C^")]?_K``!0XP4``!H$`%GC8`$`"@F0A^`%,%GE
M+P!3XUP!``JD_O_K`!!0X@0``!H'`*#AS?7_ZP`P4.(@,(WE;```&@06G^4$
M!I_E`1"/X```C^`N^__KT_7_Z_0UG^7T)9_E`S"/X`0PC>7L-9_E`B"/X.B5
MG^7HA9_EZ'6?Y0P@C>4#,(_@`"#@XP$0H.,`8(WE"9"/X`B`C^`'<(_@"`"-
MY04`H.'4]?_K#@``ZL_U_^L`,)#E$0!3XQ```!JY]?_K`:"*X@0@H.$),*#A
M`1"@XPR@C>40@(WEP`"-Z`@`C>4%`*#AQ/7_ZP<=H.,%`*#ARO7_ZP$`<.,`
M0*#AZO__"@8`H.%9]?_K7`6?Y040H.$``(_@_?K_ZP4`H.&9_O_K>___Z@:P
MH.'L4$3B"S&$X.P`$^4``%#C)```"@&0B^()887@!Q"@X8?Z_^L)L*#A`#!0
MX@(```H`,-/E``!3XP0``!H$`);D``!0XQ<```H!D(GB\O__ZE'U_^L`8%#B
MZ?__"O#^_^JH))_E(`"=Y0`PF.4"`)#GT"2?Y0``D.4"((_@!!"-Y0!@C>4!
M$*#CJ?7_ZP!0H.-5___J<?[_ZP4`H.$^]?_K`%"@X5#__^H-`*#C9_7_ZY1D
MG^53,*#C!F"/X`"@H.'@_O_J`'"8Y7C__^H$$$3B`G"@XP`PX.,1(.#C`8"@
MX0!PC>4!H*#A3/7_ZR``G>4($*#A!B"@XPGU_^L$,%3E``!3XP(``!H#,%3E
M0P!3XQ8!``H`<*#C`""@XP`PH.,@`)WE`'"-Y3SU_^OC'X_BT`#!X>,_C^+0
M(,/A^`Q$X>(?C^+0`,'A\"Q$X>$_C^+0(,/A^`M$X0X=C^+0`,'A\"M$X2A0
MC>4`(*#C`#"@X\B0C>*0@$3B"E"@X5!P!.4D<(WE^`I$X?`J1.'X*43A+&"-
MY2``G>4"*:#C!1"@X=_T_^L`L%#B20``VM`J1.&+$:#A`A"!X!@0C>4D$)WE
M'!"-Y=@!S>&4P!3E`0!3X0``4@$+8*#AF"`4Y<M_H.$!``":`2"2X@#`K.*F
M/J#AAS&#X5``%.4",)/@IRZ@X=AAS>$,P*+@``!0XP6@H`'P:D3AF#`$Y93`
M!.4;```:/P!;XQ(``-I`L$OB/W#+XX`PBN(#<(?@0&"*XD`@H.-`$$;B"`"@
MX0)@AN##]/_K"0"@X7?V_^L&`%?A]O__&BLSH.$!((/B`SUCX`*CBN`#LXO@
M"A"@X4@PH.,+(*#A"`"@X=ST_^M0L`3EP/__ZD"@8.(*`%OA"Z"@L0``B.`*
M(*#A!1"@X:ST_^M0,!3E`S"*X$``4^-0,`3EM/__&@D`H.$*L$O@"J"%X%GV
M_^O2___J(`"=Y2A0G>4L8)WE-_7_ZZ"@%.68<!3EJC&@X3\P`^)J&"K@9R@G
MX)"`1.)_`.#C(12@X2(DH.$#`,CG`3"#XO\<P>/_+,+C.`!3XVJD(>!G="+@
M7@``VD`@8^(`$*#C`P"(X/'T_^L)`*#A//;_ZP@`H.$X(*#C`!"@X^OT_^L)
M`*#A6'`$Y52@!.4T]O_KN(`4Y;!P%.7`P!3EJ.`4Y6P(+.!H&"C@9R@GX&XX
M+N`@!*#A(12@X2(DH.&XG%3A_PS`X_\<P>/_+,+C(S2@X6S$(.#_/,/C:`0A
MX&<4(N#((!3E;C0CX(RQG^4IY*#A">2.X3"@1.(\``3E(@B@X0NPC^`B+*#A
M"G"@X42`1.(QD$3B0,`$Y3@0!.4T,`3ELN1$X4,`1.4```#J`2#XY0<`H.$`
M((WE"S"@X0`@X.,!$*#CK?3_ZP@`6>$"<(?B]?__&B0QG^4D(9_E`S"/X`0P
MC>4<,9_E`B"/X```H.,,((WE"*"-Y0!@C>4#,(_@"`!$Y0`@X.,!$*#C!0"@
MX9KT_^O:_O_J!("8Y0``6..?_O\*"`"@X87T_^L#`%#CF_[_FM`0G^4$`$#B
M``"(X`$0C^`8]/_K``!0XPAPH`&3_O_J`P"(X#@@8^(`$*#CDO3_ZZ7__^H`
M`*#A`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#`````/!6
M`0"850$`&`$``/P/```H50$`I!```-@.``#`#@``J`\``)@/```H`0``=`\`
M`#!3`0`<#P``V`X``+@-```X#0``W`P``$0/``!P#@``<`X``!P/``"D#```
M!`P``)@,```T#```(`D``.0'``!,"@``:`D``!P)``!$!@``K`@``-0'```"
M,%3E00!3X^7^_QH!,%3E0P!3X^+^_QH`,-3E2`!3X]_^_QH!,-3E10!3X]S^
M_QH@0)WE`##@XSD@X.,$`*#A`'"-Y1GT_^L($*#A!`"@X2D@H./6\__K;#`?
MY6P@'^4#,(_@!#"-Y70P'^4"((_@#""-Y0,PC^``(.#C`1"@XP4`H.$(@(WE
M`&"-Y33T_^MT_O_JY_/_Z^@#G^7H$Y_E``"/X/!/+>D!$)#GW#.?Y1S03>+8
M(Y_E`S"/X``0D>44$(WE`!"@XP)0D^<08(WB``"5Y0Q@C>5F]/_K`$"@X0``
ME>5C]/_K:##4Y080H.%I,,#EG`.?Y0``C^#T^/_K``!0XP(```H`,-#E,0!3
MX[@```HQ_/_K``"5Y57T_^MT$Y_E"S"@XP$@H.,!$(_@\//_ZP``4.--```*
M7#.?Y1`@D.4#,(_@!#"3Y1B`DN4!`%/C`)"5Y48``-I`,Y_E0+.?Y0,PC^`\
MHY_E`$"@XPNPC^`)<*#A!#"-Y0H``.H0$)'E"0"@X8#S_^L$,)WE!""3Y0``
M4..:```:`D"$X@(`5.&:``"J!D"@X0<`H.$P]/_K!""@X0`PH.,($*#A#O3_
MZP`@4.(3```*`!"2Y0@`F^4(,)'E`6"$X@HP`^`!"U/C!I&0YP!PE>7C__\*
M!P"@X0@@C>4>]/_K"""=Y0(PH.,`$)+E`""@XZ'S_^L`<)7E`!"@X=G__^J,
M,I_E`)"5Y0,PC^`$,)/E`1!#X@0`4>$/```:`0!3XPT``-IL8I_E`4"@XP9@
MC^`)`*#A````Z@``E>4&]/_K"!"@X5_S_^L$,);E`4"$X@0`4^'W___*`)"5
MY0D`H.']\__K,!*?Y0,PH.,!(*#C`1"/X)CS_^L`0%#B"P``"@``E>7T\__K
M$#"4Y0PBG^4`$)/E`B"/X&[S_^L0,)3E`#"3Y0@PD^4!!1/C7@``&@``E>7H
M\__KY!&?Y0,PH.,!(*#C`1"/X(/S_^L`0%#B"P``"LP!G^4,$)WE``"/X'3X
M_^L`8%#B``"5Y44```K9\__K$#"4Y08@H.$`$)/E5//_ZP``E>73\__K`$"@
MX0``E>70\__KC!&?Y0$@H.,!$(_@@?/_ZX`AG^4"((_@`!"@X00`H.%&\__K
M``"5Y<7S_^L`,*#C#!"=Y6!1G^4%4(_@:3#`Y5@!G^4``(_@5/C_ZP``4.,`
M0*#A#`"%Y1````H'':#C!`"@X7KS_^L!,(#B$0!0XP$`4Q,M``"*)"&?Y=0P
MG^4"((_@`S"2YP`@D^44,)WE`B`SX"0``!H<T(WB\(^]Z`@`E>6(_/_K``!0
MXP!`H.$,`(7EZ/__&N@`G^4``(_@7?/_ZP$PT.4``%/C1/__"D+__^H",*#A
M!Y"@X87__^H",*#A!Y"@X09`H.&!___JD_/_Z[`PG^40()3E`S"/X`@PD^4`
M`)+E`!"3Y:CY_^NU___J``"5Y8GS_^L0,)3E`!"3Y5/S_^N:___J]/+_ZW@@
MG^4`,*#A`B"/X`@0DN5L`)_E`!"1Y00@H.$``(_@.?/_ZQ1+`0`8`0``_$H!
M`"`!``#8!0``4`<```!,`0#@2P$`U$L!```$(``@2P$`_$H!`/@%``#8!0``
ML`4``)`#``!8!0``9`4``-A)`0`$`P```$@!`,0$```420$`V$@!`%@$``!P
M0"WI`%"@X?#Z_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```
M4^/Z__\:OOO_ZP``5>,``%`3<("]"``PU>4``%/C<("]""`0G^4$`*#A!""@
MXP$0C^`Z\__K``!0XW"`O1@%`*#A<$"]Z-7X_^I0`@``\$<MZ4Q@G^5,4)_E
M!F"/X`50C^`%8$;@`'"@X0&`H.$"D*#A=/+_ZT9AL.'PA[T(`$"@XP0PE>0!
M0(3B"2"@X0@0H.$'`*#A,_\OX00`5N'W__\:\(>]Z"Q%`0`D10$`'O\OX0@P
MG^4#,(_@`#"3Y9GR_^HT1P$`"$`MZ0B`O>@!``(`+W1M<``````N````4$%2
M7U1-4$1)4@``5$5-4$1)4@!435``55-%4@````!54T523D%-10`````N+@``
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X
M90!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P``
M`%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'
M````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,
M7U1-4$1)4@```%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M`%!!4E]#3$5!3CT``#$```!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X
M`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E
M<R5S=&5M<"TE=2TE=25S`````$%21U8`````&````'!E<FP`````,````%!!
M4CHZ4&%C:V5R.CI615)324].`````#$N,#0W````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M
M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P
M<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL
M92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS
M965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F
M+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H
M)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F
M9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E
M="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D
M:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R
M97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K
M97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I
M9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A
M9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A0
M05(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I
M;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP
M<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@
M:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92![
M"F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@
M)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D
M9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP
M;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM
M;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,```!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````"\C_]_`0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````O!D``%09```!`````0````$`
M``#+`0```0```!H"```!````<P,```P```!<$@``#0```-A(```9````G(T!
M`!L````$````&@```*"-`0`<````!````/7^_V^L`0``!0```%`)```&````
MD`(```H```#I!```"P```!`````5``````````,```"TC@$``@`````"```4
M````$0```!<```!<$```$0```'0/```2````Z````!,````(````'@````@`
M``#[__]O`0``"/[__V\4#P``____;P,```#P__]O.@X``/K__V\0````````
M`````````````````````````````````````````````````*2-`0``````
M`````&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H
M$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2
M``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(`
M`&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``
M:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``!H
M$@``:!(``&@2``!H$@``:!(``&@2``!H$@``:!(``&@2``#`2```````````
M````````````````````````````````````````8$@```````"`%0``````
M``````````````````20`0#_____Y$@``.Q(````````\$@``/1(``#\2```
M@$D```1)````````"$D``!!)````````)$P``$=#0SH@*$1E8FEA;B`Y+C(N
M,2TX*2`Y+C(N,2`R,#$Y,#DP.0!!*@```&%E86)I``$@````!35410`&!`@!
M"0$2!!,!%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#D````
M!0`````````$````!````#X````+`````@```)`"``"0`@``P`8```8````#
M````!````!````!&`````P````(```!0"0``4`D``.D$``````````````$`
M````````3@```/___V\"````.@X``#H.``#8````!0`````````"`````@``
M`%L```#^__]O`@```!0/```4#P``8`````8````#````!`````````!J````
M"0````(```!T#P``=`\``.@````%``````````0````(````<P````D```!"
M````7!```%P0`````@``!0```!4````$````"````'P````!````!@```%P2
M``!<$@``#```````````````!`````````!W`````0````8```!H$@``:!(`
M`!0#``````````````0````$````@@````$````&````@!4``(`5``!8,P``
M```````````(`````````(@````!````!@```-A(``#82```"```````````
M````!`````````".`````0````(```#@2```X$@``*8_``````````````0`
M````````E@````$``'""````B(@``(B(```(````#0`````````$````````
M`*$````!`````@```)"(``"0B```!```````````````!`````````"K````
M#@````,```"<C0$`G(T```0```````````````0````$````MP````\````#
M````H(T!`*"-```$```````````````$````!````,,````&`````P```*2-
M`0"DC0``$`$```8`````````!`````@```#,`````0````,```"TC@$`M(X`
M`$P!``````````````0````$````T0````$````#`````)`!``"0``!`````
M```````````$`````````-<````(`````P```$"0`0!`D```&!``````````
M````!`````````#<`````0```#``````````0)```"4```````````````$`
M```!````Y0````,``'```````````&60```K```````````````!````````
I``$````#``````````````"0D```]0```````````````0``````````
